"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _ReactNativeFeatureFlags = _interopRequireDefault(require("react-native/Libraries/ReactNative/ReactNativeFeatureFlags"));

var _reactNative = require("react-native");

var _TextAncestor = _interopRequireDefault(require("react-native/Libraries/Text/TextAncestor"));

var _ShadowViewNativeComponent = _interopRequireDefault(require("./ShadowViewNativeComponent"));

var React = _interopRequireWildcard(require("react"));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

/**
 * The most fundamental component for building a UI, View is a container that
 * supports layout with flexbox, style, some touch handling, and accessibility
 * controls.
 *
 * @see https://reactnative.dev/docs/view
 */
const ShadowView = /*#__PURE__*/React.forwardRef((_ref, forwardedRef) => {
  let {
    accessibilityElementsHidden,
    accessibilityLabel,
    accessibilityLabelledBy,
    accessibilityLiveRegion,
    accessibilityState,
    accessibilityValue,
    'aria-busy': ariaBusy,
    'aria-checked': ariaChecked,
    'aria-disabled': ariaDisabled,
    'aria-expanded': ariaExpanded,
    'aria-hidden': ariaHidden,
    'aria-label': ariaLabel,
    'aria-labelledby': ariaLabelledBy,
    'aria-live': ariaLive,
    'aria-selected': ariaSelected,
    'aria-valuemax': ariaValueMax,
    'aria-valuemin': ariaValueMin,
    'aria-valuenow': ariaValueNow,
    'aria-valuetext': ariaValueText,
    focusable,
    id,
    importantForAccessibility,
    nativeID,
    pointerEvents,
    // @ts-ignore: web only
    tabIndex,
    ...otherProps
  } = _ref;
  const hasTextAncestor = React.useContext(_TextAncestor.default);

  const _accessibilityLabelledBy = (ariaLabelledBy === null || ariaLabelledBy === void 0 ? void 0 : ariaLabelledBy.split(/\s*,\s*/g)) ?? accessibilityLabelledBy;

  let _accessibilityState;

  if (accessibilityState != null || ariaBusy != null || ariaChecked != null || ariaDisabled != null || ariaExpanded != null || ariaSelected != null) {
    _accessibilityState = {
      busy: ariaBusy ?? (accessibilityState === null || accessibilityState === void 0 ? void 0 : accessibilityState.busy),
      checked: ariaChecked ?? (accessibilityState === null || accessibilityState === void 0 ? void 0 : accessibilityState.checked),
      disabled: ariaDisabled ?? (accessibilityState === null || accessibilityState === void 0 ? void 0 : accessibilityState.disabled),
      expanded: ariaExpanded ?? (accessibilityState === null || accessibilityState === void 0 ? void 0 : accessibilityState.expanded),
      selected: ariaSelected ?? (accessibilityState === null || accessibilityState === void 0 ? void 0 : accessibilityState.selected)
    };
  }

  let _accessibilityValue;

  if (accessibilityValue != null || ariaValueMax != null || ariaValueMin != null || ariaValueNow != null || ariaValueText != null) {
    _accessibilityValue = {
      max: ariaValueMax ?? (accessibilityValue === null || accessibilityValue === void 0 ? void 0 : accessibilityValue.max),
      min: ariaValueMin ?? (accessibilityValue === null || accessibilityValue === void 0 ? void 0 : accessibilityValue.min),
      now: ariaValueNow ?? (accessibilityValue === null || accessibilityValue === void 0 ? void 0 : accessibilityValue.now),
      text: ariaValueText ?? (accessibilityValue === null || accessibilityValue === void 0 ? void 0 : accessibilityValue.text)
    };
  } // $FlowFixMe[underconstrained-implicit-instantiation]


  let style = _reactNative.StyleSheet.flatten(otherProps.style); // $FlowFixMe[sketchy-null-mixed]


  const newPointerEvents = (style === null || style === void 0 ? void 0 : style.pointerEvents) || pointerEvents;
  const collapsableOverride = _ReactNativeFeatureFlags.default.shouldForceUnflattenForElevation() ? {
    collapsable: style != null && style.elevation != null && style.elevation !== 0 ? false : otherProps.collapsable
  } : {};
  const actualView = /*#__PURE__*/React.createElement(_ShadowViewNativeComponent.default, _extends({}, otherProps, collapsableOverride, {
    accessibilityLiveRegion: ariaLive === 'off' ? 'none' : ariaLive ?? accessibilityLiveRegion,
    accessibilityLabel: ariaLabel ?? accessibilityLabel,
    focusable: tabIndex !== undefined ? !tabIndex : focusable,
    accessibilityState: _accessibilityState,
    accessibilityElementsHidden: ariaHidden ?? accessibilityElementsHidden,
    accessibilityLabelledBy: _accessibilityLabelledBy,
    accessibilityValue: _accessibilityValue,
    importantForAccessibility: ariaHidden === true ? 'no-hide-descendants' : importantForAccessibility,
    nativeID: id ?? nativeID,
    style: style // $FlowFixMe[incompatible-type]
    ,
    pointerEvents: newPointerEvents,
    ref: forwardedRef
  }));

  if (hasTextAncestor) {
    return /*#__PURE__*/React.createElement(_TextAncestor.default.Provider, {
      value: false
    }, actualView);
  }

  return actualView;
});
ShadowView.displayName = 'ShadowView';
var _default = ShadowView;
exports.default = _default;
//# sourceMappingURL=index.android.js.map